summaryrefslogtreecommitdiffstats
path: root/knode/kncollectionview.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /knode/kncollectionview.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'knode/kncollectionview.cpp')
-rw-r--r--knode/kncollectionview.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/knode/kncollectionview.cpp b/knode/kncollectionview.cpp
index 40cce774..ef97c653 100644
--- a/knode/kncollectionview.cpp
+++ b/knode/kncollectionview.cpp
@@ -32,8 +32,8 @@
#include "kncollectionview.h"
#include "kncollectionviewitem.h"
-KNCollectionView::KNCollectionView(TQWidget *parent, const char* name) :
- KFolderTree(parent, name),
+KNCollectionView::KNCollectionView(TQWidget *tqparent, const char* name) :
+ KFolderTree(tqparent, name),
mActiveItem( 0 ),
mPopup( 0 )
{
@@ -221,13 +221,13 @@ void KNCollectionView::addFolder(KNFolder *f)
{
KNCollectionViewItem *it;
- if (!f->parent()) {
+ if (!f->tqparent()) {
// root folder
it = new KNCollectionViewItem(this, KFolderTreeItem::Local);
} else {
- // make sure the parent folder has already been added
- if (!f->parent()->listItem())
- addFolder( static_cast<KNFolder*>(f->parent()) );
+ // make sure the tqparent folder has already been added
+ if (!f->tqparent()->listItem())
+ addFolder( static_cast<KNFolder*>(f->tqparent()) );
// handle special folders
KFolderTreeItem::Type type = KFolderTreeItem::Other;
switch ( f->id() ) {
@@ -238,7 +238,7 @@ void KNCollectionView::addFolder(KNFolder *f)
case 3:
type = KFolderTreeItem::SentMail; break;
}
- it = new KNCollectionViewItem( f->parent()->listItem(), KFolderTreeItem::Local, type );
+ it = new KNCollectionViewItem( f->tqparent()->listItem(), KFolderTreeItem::Local, type );
}
f->setListItem( it );
updateFolder( f );